package com.mycompany.ctfposhbot_b;

import java.io.IOException;
import java.util.logging.Level;

import cz.cuni.amis.pogamut.sposh.ut2004.StateSposhLogicController;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.AgentInfo;
import cz.cuni.amis.pogamut.ut2004.agent.module.sensor.WeaponPrefs;
import cz.cuni.amis.pogamut.ut2004.bot.IUT2004BotController;
import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004Bot;
import cz.cuni.amis.pogamut.ut2004.bot.params.UT2004BotParameters;
import cz.cuni.amis.pogamut.ut2004.communication.messages.ItemType;
import cz.cuni.amis.pogamut.ut2004.communication.messages.gbcommands.Initialize;
import cz.cuni.amis.pogamut.ut2004.communication.messages.gbinfomessages.BotKilled;
import cz.cuni.amis.pogamut.ut2004.utils.UT2004BotRunner;
import cz.cuni.amis.utils.exception.PogamutException;

/**
 * Create simple bot that is standing still and when its health falls under 90,
 * it runs around the map, looking for medkits.
 * @see IUT2004BotController Controller for various methods called during construction of bot.
 * @author Honza
 */
public class CTFLogic extends StateSposhLogicController<UT2004Bot, CTFContext> {
    private String SPOSH_PLAN_RESOURCE = "sposh/plan/BotPlan.lap";

    /**
     * Bot's preparation - called before the bot is connected to GB2004 and
     * launched into UT2004.
     */
    @Override
    public void prepareBot(UT2004Bot bot) {
		
		WeaponPrefs weaponPrefs = context.getWeaponPrefs();
		
        // DEFINE WEAPON PREFERENCES
        weaponPrefs.addGeneralPref(ItemType.SHOCK_RIFLE, true);
        weaponPrefs.addGeneralPref(ItemType.MINIGUN, false);
        weaponPrefs.addGeneralPref(ItemType.MINIGUN, true);
        weaponPrefs.addGeneralPref(ItemType.LINK_GUN, false);
        weaponPrefs.addGeneralPref(ItemType.LIGHTNING_GUN, true);
        weaponPrefs.addGeneralPref(ItemType.ROCKET_LAUNCHER, true);
        weaponPrefs.addGeneralPref(ItemType.LINK_GUN, true);
        weaponPrefs.addGeneralPref(ItemType.ASSAULT_RIFLE, true);
        weaponPrefs.addGeneralPref(ItemType.FLAK_CANNON, false);
        weaponPrefs.addGeneralPref(ItemType.FLAK_CANNON, true);
        weaponPrefs.addGeneralPref(ItemType.BIO_RIFLE, true);
		
		weaponPrefs.newPrefsRange(500)
				.add(ItemType.FLAK_CANNON, true)
				.add(ItemType.MINIGUN, true)
				.add(ItemType.LIGHTNING_GUN, true)
				.add(ItemType.ROCKET_LAUNCHER, true)
				.add(ItemType.FLAK_CANNON, false);
		
		weaponPrefs.newPrefsRange(1500)
				.add(ItemType.MINIGUN, false)
				.add(ItemType.LIGHTNING_GUN, true);
				
		
    }

    @Override
    protected String getPlan() throws IOException {
        return getPlanFromResource(SPOSH_PLAN_RESOURCE);
    }

    /**
     * Create context that can be accessed in every state primitive.
     * @return new context of this bot.
     */
    @Override
    protected CTFContext createContext() {
        return new CTFContext(bot);
    }

    /**
     * Initialize command of the bot, called during initial handshake, init can
     * set things like name of bot, its skin, skill, team ect.
     * @see Initialize
     * @return
     */
    @Override
    public Initialize getInitializeCommand() {
        return new Initialize().setName("SPOSH-Modular-Prey");
    }

    @Override
    public void botKilled(BotKilled event) {
    }

    /**
     * Create an {@link ExternalBot} with custom made logic and
     * try to connect to Unreal Server at localhost:3000
     *
     * @param args the command line arguments
     */
    public static void main(String[] args) throws PogamutException {
        new UT2004BotRunner<UT2004Bot, UT2004BotParameters>(CTFLogic.class, "CTFPoshBot-B").setMain(true).setLogLevel(Level.WARNING).startAgents(
                new UT2004BotParameters().setTeam(AgentInfo.TEAM_BLUE),
                new UT2004BotParameters().setTeam(AgentInfo.TEAM_RED)
        );
    }
}
